# aiida-icon

[![PyPI - Version](https://img.shields.io/pypi/v/aiida-icon.svg)](https://pypi.org/project/aiida-icon)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/aiida-icon.svg)](https://pypi.org/project/aiida-icon)

---

[AiiDA](www.aiida.net) plugin to run the [ICON Weather & Climate Model](https://icon-model.org/) as part of HPC workflows.

Full documentation is [here](https://aiida-icon.github.io/aiida-icon/)

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install aiida-icon
```

## License

`aiida-icon` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
